@@ -62,6 +62,7 @@ my %hierarchy = (
     'ColorChangeEffect' => 'ImageTransformEffect',
     'ColorReplaceEffect' => 'ImageTransformEffect',
     'ColorScheme' => 'ResourceBase',
+    'CommentAuthors' => 'ResourceBase',
     'Connector' => 'GeometryShape',
     'CubicBezierToPathSegment' => 'PathSegment',
     'DelimiterElement' => 'MathElement',
@@ -231,6 +232,8 @@ my %determiners = (
     'ColorChangeEffect' => { 'Type' => 'ColorChange', },
     'ColorReplaceEffect' => { 'Type' => 'ColorReplace', },
     'ColorScheme' => {  },
+    'CommentAuthor' => {  },
+    'CommentAuthors' => {  },
     'CommonSlideViewProperties' => {  },
     'Connector' => { 'Type' => 'Connector', },
     'CubicBezierToPathSegment' => { 'Type' => 'CubicBezierTo', },
